
# Slot: street




URI: [ks:street](https://w3id.org/linkml/tests/kitchen_sink/street)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](String.md)

## Parents


## Children


## Used by

 * [Address](Address.md)
